@@ -205,7 +205,16 @@ ypresp_val *ypproc_match_2_svc(ypreq_key *key, struct svc_req *rqstp)
 	    gdbm_close(dbp);
 	}
     }
-	
+
+    if (debug_flag)
+    {
+	if (result.stat == YP_TRUE)
+	    fprintf(stderr, "\t-> Value = \"%.*s\"\n",
+		    result.val.valdat_len, result.val.valdat_val);
+	else
+	    fprintf(stderr, "\t-> Error #%d\n", result.stat);
+    }
+    
     return &result;
 }
 
@@ -265,8 +274,19 @@ ypresp_key_val *ypproc_first_2_svc(ypreq_key *key, struct svc_req *rqstp)
 		result.val.valdat_len = dval.dsize;
 		result.val.valdat_val = dval.dptr;
 	    }
+	    gdbm_close(dbp);
 	}
-	gdbm_close(dbp);
+    }
+    
+    if (debug_flag)
+    {
+	if (result.stat == YP_TRUE)
+	    fprintf(stderr, "\t-> Key = \"%s\", Value = \"%.*s\"\n",
+		    result.key.keydat_len, result.key.keydat_val,
+		    result.val.valdat_len, result.val.valdat_val);
+		    
+	else
+	    fprintf(stderr, "\t-> Error #%d\n", result.stat);
     }
     
     return &result;
@@ -352,6 +372,16 @@ ypresp_key_val *ypproc_next_2_svc(ypreq_key *key, struct svc_req *rqstp)
 	}
     }
 
+    if (debug_flag)
+    {
+	if (result.stat == YP_TRUE)
+	    fprintf(stderr, "\t-> Key = \"%s\", Value = \"%.*s\"\n",
+		    result.key.keydat_len, result.key.keydat_val,
+		    result.val.valdat_len, result.val.valdat_val);
+	else
+	    fprintf(stderr, "\t-> Error #%d\n", result.stat);
+    }
+
     return &result;
 }
 
@@ -611,10 +641,29 @@ ypresp_maplist *ypproc_maplist_2_svc(domainname *name, struct svc_req *rqstp)
 		    result.stat = YP_YPERR;
 		    break;
 		}
+	    
+	    closedir(dp);
 	}
-
-	closedir(dp);
     }
-    
+
+    if (debug_flag)
+    {
+	if (result.stat == YP_TRUE)
+	{
+	    ypmaplist *p;
+
+	    p = result.maps;
+	    fprintf(stderr, "-> ");
+	    while (p)
+	    {
+		fprintf(stderr, "%s", p->map);
+		if (p->next)
+		    fprintf(stderr, ", ");
+	    }
+	    putc('\n', stderr);
+	}
+	else
+	    fprintf(stderr, "\t-> Error #%d\n", result.stat);
+    }
     return &result;
 }
